"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const api = require("../../../scw/api.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const resourcePaginator = require("../../../scw/fetch/resource-paginator.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class GlobalAPI extends api.API {
  /**
   * Get your Cockpit's Grafana. Retrieve information on your Cockpit's Grafana,
   * specified by the ID of the Project the Cockpit belongs to. The output
   * returned displays the URL to access your Cockpit's Grafana.
   *
   * @param request - The request {@link GlobalApiGetGrafanaRequest}
   * @returns A Promise of Grafana
   */
  getGrafana = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/grafana`,
      urlParams: marshalling.urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    marshalling_gen.unmarshalGrafana
  );
  /**
   * Synchronize Grafana data sources. Trigger the synchronization of all your
   * data sources and the alert manager in the relevant regions. The alert
   * manager will only be synchronized if you have enabled it.
   *
   * @param request - The request {@link GlobalApiSyncGrafanaDataSourcesRequest}
   */
  syncGrafanaDataSources = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalGlobalApiSyncGrafanaDataSourcesRequest(
        request,
        this.client.settings
      )
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1/grafana/sync-data-sources`
  });
  /**
   * Create a Grafana user. Create a Grafana user to connect to your Cockpit's
   * Grafana. Upon creation, your user password displays only once, so make sure
   * that you save it. Each Grafana user is associated with a role: viewer or
   * editor. A viewer can only view dashboards, whereas an editor can create and
   * edit dashboards. Note that the `admin` username is not available for
   * creation.
   *
   * @param request - The request {@link GlobalApiCreateGrafanaUserRequest}
   * @returns A Promise of GrafanaUser
   */
  createGrafanaUser = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalGlobalApiCreateGrafanaUserRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/grafana/users`
    },
    marshalling_gen.unmarshalGrafanaUser
  );
  pageOfListGrafanaUsers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/grafana/users`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalListGrafanaUsersResponse
  );
  /**
   * List Grafana users. List all Grafana users created in your Cockpit's
   * Grafana. By default, the Grafana users returned in the list are ordered in
   * ascending order.
   *
   * @param request - The request {@link GlobalApiListGrafanaUsersRequest}
   * @returns A Promise of ListGrafanaUsersResponse
   */
  listGrafanaUsers = (request = {}) => resourcePaginator.enrichForPagination("grafanaUsers", this.pageOfListGrafanaUsers, request);
  /**
   * Delete a Grafana user. Delete a Grafana user from your Cockpit's Grafana,
   * specified by the ID of the Project the Cockpit belongs to, and the ID of
   * the Grafana user.
   *
   * @param request - The request {@link GlobalApiDeleteGrafanaUserRequest}
   */
  deleteGrafanaUser = (request) => this.client.fetch({
    method: "DELETE",
    path: `/cockpit/v1/grafana/users/${marshalling.validatePathParam("grafanaUserId", request.grafanaUserId)}`,
    urlParams: marshalling.urlParams([
      "project_id",
      request.projectId ?? this.client.settings.defaultProjectId
    ])
  });
  /**
   * Reset a Grafana user password. Reset the password of a Grafana user,
   * specified by the ID of the Project the Cockpit belongs to, and the ID of
   * the Grafana user. A new password regenerates and only displays once. Make
   * sure that you save it.
   *
   * @param request - The request
   *   {@link GlobalApiResetGrafanaUserPasswordRequest}
   * @returns A Promise of GrafanaUser
   */
  resetGrafanaUserPassword = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalGlobalApiResetGrafanaUserPasswordRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/grafana/users/${marshalling.validatePathParam("grafanaUserId", request.grafanaUserId)}/reset-password`
    },
    marshalling_gen.unmarshalGrafanaUser
  );
  pageOfListGrafanaProductDashboards = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/grafana/product-dashboards`,
      urlParams: marshalling.urlParams(
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["tags", request.tags]
      )
    },
    marshalling_gen.unmarshalListGrafanaProductDashboardsResponse
  );
  /**
   * List Scaleway resources dashboards. Retrieve a list of available dashboards
   * in Grafana, for all Scaleway resources which are integrated with Cockpit.
   *
   * @param request - The request
   *   {@link GlobalApiListGrafanaProductDashboardsRequest}
   * @returns A Promise of ListGrafanaProductDashboardsResponse
   */
  listGrafanaProductDashboards = (request = {}) => resourcePaginator.enrichForPagination(
    "dashboards",
    this.pageOfListGrafanaProductDashboards,
    request
  );
  /**
   * Get Scaleway resource dashboard. Retrieve information about the dashboard
   * of a Scaleway resource in Grafana, specified by the ID of the Project the
   * Cockpit belongs to, and the name of the dashboard.
   *
   * @param request - The request
   *   {@link GlobalApiGetGrafanaProductDashboardRequest}
   * @returns A Promise of GrafanaProductDashboard
   */
  getGrafanaProductDashboard = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/grafana/product-dashboards/${marshalling.validatePathParam("dashboardName", request.dashboardName)}`,
      urlParams: marshalling.urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    marshalling_gen.unmarshalGrafanaProductDashboard
  );
  pageOfListPlans = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/plans`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListPlansResponse
  );
  /**
   * List plan types. Retrieve a list of available pricing plan types.
   *
   * @param request - The request {@link GlobalApiListPlansRequest}
   * @returns A Promise of ListPlansResponse
   */
  listPlans = (request = {}) => resourcePaginator.enrichForPagination("plans", this.pageOfListPlans, request);
  /**
   * Apply a pricing plan. Apply a pricing plan on a given Project. You must
   * specify the ID of the pricing plan type. Note that you will be billed for
   * the plan you apply.
   *
   * @param request - The request {@link GlobalApiSelectPlanRequest}
   * @returns A Promise of Plan
   */
  selectPlan = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalGlobalApiSelectPlanRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/cockpit/v1/plans`
    },
    marshalling_gen.unmarshalPlan
  );
  /**
   * Get current plan. Retrieve a pricing plan for the given Project, specified
   * by the ID of the Project.
   *
   * @param request - The request {@link GlobalApiGetCurrentPlanRequest}
   * @returns A Promise of Plan
   */
  getCurrentPlan = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/current-plan`,
      urlParams: marshalling.urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    marshalling_gen.unmarshalPlan
  );
}
class RegionalAPI extends api.API {
  /** Lists the available regions of the API. */
  static LOCALITIES = ["fr-par", "nl-ams", "pl-waw"];
  /**
   * Create a data source. You must specify the data source type upon creation.
   * Available data source types include:
   *
   * - Metrics
   * - Logs
   * - Traces The name of the data source will then be used as reference to name
   *   the associated Grafana data source.
   *
   * @param request - The request {@link RegionalApiCreateDataSourceRequest}
   * @returns A Promise of DataSource
   */
  createDataSource = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiCreateDataSourceRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/data-sources`
    },
    marshalling_gen.unmarshalDataSource
  );
  /**
   * Get a data source. Retrieve information about a given data source,
   * specified by the data source ID. The data source's information such as its
   * name, type, URL, origin, and retention period, is returned.
   *
   * @param request - The request {@link RegionalApiGetDataSourceRequest}
   * @returns A Promise of DataSource
   */
  getDataSource = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/data-sources/${marshalling.validatePathParam("dataSourceId", request.dataSourceId)}`
    },
    marshalling_gen.unmarshalDataSource
  );
  /**
   * Delete a data source. Delete a given data source, specified by the data
   * source ID. Note that deleting a data source is irreversible, and cannot be
   * undone.
   *
   * @param request - The request {@link RegionalApiDeleteDataSourceRequest}
   */
  deleteDataSource = (request) => this.client.fetch({
    method: "DELETE",
    path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/data-sources/${marshalling.validatePathParam("dataSourceId", request.dataSourceId)}`
  });
  pageOfListDataSources = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/data-sources`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["origin", request.origin],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["types", request.types]
      )
    },
    marshalling_gen.unmarshalListDataSourcesResponse
  );
  /**
   * List data sources. Retrieve the list of data sources available in the
   * specified region. By default, the data sources returned in the list are
   * ordered by creation date, in ascending order. You can list data sources by
   * Project, type and origin.
   *
   * @param request - The request {@link RegionalApiListDataSourcesRequest}
   * @returns A Promise of ListDataSourcesResponse
   */
  listDataSources = (request = {}) => resourcePaginator.enrichForPagination("dataSources", this.pageOfListDataSources, request);
  /**
   * Update a data source. Update a given data source name, specified by the
   * data source ID.
   *
   * @param request - The request {@link RegionalApiUpdateDataSourceRequest}
   * @returns A Promise of DataSource
   */
  updateDataSource = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiUpdateDataSourceRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/data-sources/${marshalling.validatePathParam("dataSourceId", request.dataSourceId)}`
    },
    marshalling_gen.unmarshalDataSource
  );
  /**
   * Get data source usage overview. Retrieve the data source usage overview per
   * type for the specified Project.
   *
   * @param request - The request {@link RegionalApiGetUsageOverviewRequest}
   * @returns A Promise of UsageOverview
   */
  getUsageOverview = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/usage-overview`,
      urlParams: marshalling.urlParams(
        ["interval", request.interval],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalUsageOverview
  );
  /**
   * Create a token. Give your token the relevant scopes to ensure it has the
   * right permissions to interact with your data sources and the Alert manager.
   * Make sure that you create your token in the same regions as the data
   * sources you want to use it for. Upon creation, your token's secret key
   * display only once. Make sure that you save it.
   *
   * @param request - The request {@link RegionalApiCreateTokenRequest}
   * @returns A Promise of Token
   */
  createToken = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiCreateTokenRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/tokens`
    },
    marshalling_gen.unmarshalToken
  );
  pageOfListTokens = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/tokens`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["token_scopes", request.tokenScopes]
      )
    },
    marshalling_gen.unmarshalListTokensResponse
  );
  /**
   * List tokens. Retrieve a list of all tokens in the specified region. By
   * default, tokens returned in the list are ordered by creation date, in
   * ascending order. You can filter tokens by Project ID and token scopes.
   *
   * @param request - The request {@link RegionalApiListTokensRequest}
   * @returns A Promise of ListTokensResponse
   */
  listTokens = (request = {}) => resourcePaginator.enrichForPagination("tokens", this.pageOfListTokens, request);
  /**
   * Get a token. Retrieve information about a given token, specified by the
   * token ID. The token's information such as its scopes, is returned.
   *
   * @param request - The request {@link RegionalApiGetTokenRequest}
   * @returns A Promise of Token
   */
  getToken = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/tokens/${marshalling.validatePathParam("tokenId", request.tokenId)}`
    },
    marshalling_gen.unmarshalToken
  );
  /**
   * Delete a token. Delete a given token, specified by the token ID. Deleting a
   * token is irreversible and cannot be undone.
   *
   * @param request - The request {@link RegionalApiDeleteTokenRequest}
   */
  deleteToken = (request) => this.client.fetch({
    method: "DELETE",
    path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/tokens/${marshalling.validatePathParam("tokenId", request.tokenId)}`
  });
  /**
   * Get the Alert manager. Retrieve information about the Alert manager which
   * is unique per Project and region. By default the Alert manager is disabled.
   * The output returned displays a URL to access the Alert manager, and whether
   * the Alert manager and managed alerts are enabled.
   *
   * @param request - The request {@link RegionalApiGetAlertManagerRequest}
   * @returns A Promise of AlertManager
   */
  getAlertManager = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager`,
      urlParams: marshalling.urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    marshalling_gen.unmarshalAlertManager
  );
  /**
   * Enable the Alert manager. Enabling the Alert manager allows you to enable
   * managed alerts and create contact points in the specified Project and
   * region, to be notified when your Scaleway resources may require your
   * attention.
   *
   * @param request - The request {@link RegionalApiEnableAlertManagerRequest}
   * @returns A Promise of AlertManager
   */
  enableAlertManager = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiEnableAlertManagerRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/enable`
    },
    marshalling_gen.unmarshalAlertManager
  );
  /**
   * Disable the Alert manager. Disabling the Alert manager deletes the contact
   * points you have created and disables managed alerts in the specified
   * Project and region.
   *
   * @param request - The request {@link RegionalApiDisableAlertManagerRequest}
   * @returns A Promise of AlertManager
   */
  disableAlertManager = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiDisableAlertManagerRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/disable`
    },
    marshalling_gen.unmarshalAlertManager
  );
  /**
   * Create a contact point. Contact points are email addresses associated with
   * the default receiver, that the Alert manager sends alerts to. The source of
   * the alerts are data sources within the same Project and region as the Alert
   * manager. If you need to receive alerts for other receivers, you can create
   * additional contact points and receivers in Grafana. Make sure that you
   * select the Scaleway Alert manager.
   *
   * @param request - The request {@link RegionalApiCreateContactPointRequest}
   * @returns A Promise of ContactPoint
   */
  createContactPoint = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiCreateContactPointRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/contact-points`
    },
    marshalling_gen.unmarshalContactPoint
  );
  pageOfListContactPoints = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/contact-points`,
      urlParams: marshalling.urlParams(
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalListContactPointsResponse
  );
  /**
   * List contact points. Retrieve a list of contact points for the specified
   * Project. The response lists all contact points and receivers created in
   * Grafana or via the API.
   *
   * @param request - The request {@link RegionalApiListContactPointsRequest}
   * @returns A Promise of ListContactPointsResponse
   */
  listContactPoints = (request = {}) => resourcePaginator.enrichForPagination("contactPoints", this.pageOfListContactPoints, request);
  /**
   * Delete a contact point. Delete a contact point associated with the default
   * receiver.
   *
   * @param request - The request {@link RegionalApiDeleteContactPointRequest}
   */
  deleteContactPoint = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalRegionalApiDeleteContactPointRequest(
        request,
        this.client.settings
      )
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/contact-points/delete`
  });
  pageOfListManagedAlerts = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/managed-alerts`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalListManagedAlertsResponse
  );
  /**
   * List managed alerts. List all managed alerts for the specified Project.
   *
   * @param request - The request {@link RegionalApiListManagedAlertsRequest}
   * @returns A Promise of ListManagedAlertsResponse
   */
  listManagedAlerts = (request = {}) => resourcePaginator.enrichForPagination("alerts", this.pageOfListManagedAlerts, request);
  /**
   * Enable managed alerts. Enable the sending of managed alerts for the
   * specified Project. Managed alerts are predefined alerts that apply to
   * Scaleway recources integrated with Cockpit by default.
   *
   * @param request - The request {@link RegionalApiEnableManagedAlertsRequest}
   * @returns A Promise of AlertManager
   */
  enableManagedAlerts = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiEnableManagedAlertsRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/managed-alerts/enable`
    },
    marshalling_gen.unmarshalAlertManager
  );
  /**
   * Disable managed alerts. Disable the sending of managed alerts for the
   * specified Project.
   *
   * @param request - The request {@link RegionalApiDisableManagedAlertsRequest}
   * @returns A Promise of AlertManager
   */
  disableManagedAlerts = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalRegionalApiDisableManagedAlertsRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/managed-alerts/disable`
    },
    marshalling_gen.unmarshalAlertManager
  );
  /**
   * Trigger a test alert. Send a test alert to the Alert manager to make sure
   * your contact points get notified.
   *
   * @param request - The request {@link RegionalApiTriggerTestAlertRequest}
   */
  triggerTestAlert = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalRegionalApiTriggerTestAlertRequest(
        request,
        this.client.settings
      )
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/alert-manager/trigger-test-alert`
  });
}
exports.GlobalAPI = GlobalAPI;
exports.RegionalAPI = RegionalAPI;
